﻿; CloseWindow.ahk[UTF-8] (2024/03/20 04:00)
; for AutoHotKey v2.0.12.0 or later
;
; フルパスで指定されるウィンドウを終了します。
;
; 使い方
;  CloseWindow.exe C "C:\Prog略\VivaldiStandAlone1\vivaldi.exe"
;
;   第1パラメータ C/K  C=[close] ウィンドウを閉じる(アプリによっては確認ダイアログなどが出て終わらない),
;                      K=[kill]  強制終了(アプリによっては最終状態が保存されない)
;                 /c --C -close などスラッシュまたはハイフンをつけてもつけなくても大文字でも小文字でも動作
;   第2パラメータ 閉じるウィンドウのフルパス、両端は""で囲う
;
;

/* コマンドオプション数チェック */
if( A_Args.Length < 2 ){
	MsgBox("Usage:`nCloseWindow.exe C/K FullPath")
	ExitApp
}

/* 同時に複数実行を許可する */
#SingleInstance Off

/* 非表示になっているアプリも対象とする（仮想デスクトップ上では非表示扱い？） */
#WinActivateForce
DetectHiddenWindows True

WS_POPUP        := 0x80000000
WS_CHILD        := 0x40000000
WS_MINIMIZE     := 0x20000000
WS_VISIBLE      := 0x10000000
WS_DISABLED     := 0x08000000
WS_CLIPSIBLINGS := 0x04000000
WS_CLIPCHILDREN := 0x02000000
WS_MAXIMIZE     := 0x01000000
WS_BORDER       := 0x00800000
WS_DLGFRAME     := 0x00400000
WS_VSCROLL      := 0x00200000
WS_HSCROLL      := 0x00100000
WS_SYSMENU      := 0x00080000
WS_SIZEBOX      := 0x00040000
WS_MINIMIZEBOX  := 0x00020000
WS_MAXIMIZEBOX  := 0x00010000
WS_OVERLAPPED   := 0x00000000


/* 変数初期化 */
count := 0
mode := StrUpper(A_Args[1])
mode := StrReplace(mode, '-', "")
mode := StrReplace(mode, '/', "")
if( mode == "CLOSE" ){
	mode := "C"
}
if( mode == "KILL" ){
	mode := "K"
}
arg_path := StrReplace(A_Args[2], '"', "")

listWin := WinGetList("ahk_exe " arg_path)
for hWnd in listWin{
	count++
	try{
		Style := WinGetStyle( "ahk_id " hWnd )
		;MsgBox("hWnd=" hWnd " Style=0x" SubStr("00000000" StrUpper(Format("{1:X}",Style)),-8))
	} catch Error as err {
		hWnd := 0
	}
	if( Style & WS_VISIBLE and not( Style & WS_DISABLED) and hWnd != 0 ){
		if( mode == "C" ){
			try {
				WinClose( "ahk_id " hWnd )
			} catch TargetError as err {
				;MsgBox( arg_path " not found[WinClose]" )
			}
		} else if( mode == "K" ){
			try {
				WinKill( "ahk_id " hWnd )
			} catch TargetError as err {
				;MsgBox( arg_path " not found[WinKill]" )
			}
		}
	}
}

ExitApp

